@@ -218,10 +218,12 @@ OpenLook::animateIconifyOrDeiconify(bool iconify)
 
   p.setRasterOp(Qt::NotROP);
 
+#if 0
   if (iconify)
     p.setClipRegion(
       QRegion(workspace()->desktopWidget()->rect()) - wingeom
       );
+#endif
 
   for (uint count = 0; count < 4; count++)
   {
